import React from 'react'
import { useForm } from "react-hook-form";
import { yupResolver } from '@hookform/resolvers/yup';
import * as yup from "yup";

const schema = yup.object().shape({
  firstName: yup.string().required(),
  lastName: yup.string().required(),
  email: yup.string().email().required(),
  password: yup.string().required(),
});


export default function LoginForm() {
  const { register, handleSubmit, watch, formState: { errors } } = useForm({
    resolver: yupResolver(schema)
  });
  const onSubmit = (data: any) => console.log(data);

  console.log(watch("example")); // watch input value by passing the name of it

  return (
    /* "handleSubmit" will validate your inputs before invoking "onSubmit" */
    <form onSubmit={handleSubmit(onSubmit)}>
      {/* register your input into the hook by invoking the "register" function */}
      <input defaultValue="First name" {...register("firstName", { required: true })} />
      {/* include validation with required or other standard HTML validation rules */}
      <input defaultValue="Last name" {...register("lastName", { required: true })} />
      <input defaultValue="Email" {...register("email", { required: true })} />
      <input  defaultValue="Password" {...register("password", { required: true })} />
      {/* errors will return when field validation fails  */}
      {errors.password&& <span>This field is required</span>}
      <input type="submit" />
    </form>
  );
}
